@@ -1,4 +1,4 @@
-<?php # $Id: entries_overview.inc.php 981 2006-02-27 13:26:51Z garvinhicking $
+<?php # $Id: entries_overview.inc.php 2100 2008-02-01 14:10:14Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 /* vim: set sts=4 ts=4 expandtab : */
@@ -7,6 +7,6 @@ if (IN_serendipity !== true) {
     die ('Don\'t hack!');
 }
 
-echo WELCOME_BACK . ' ' . $_SESSION['serendipityUser'];
+echo WELCOME_BACK . ' ' . htmlspecialchars($_SESSION['serendipityUser']);
 
 ?>
