@@ -1,4 +1,4 @@
-<?php # $Id: images.inc.php 1767 2007-07-12 09:36:32Z garvinhicking $
+<?php # $Id: images.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -360,6 +360,8 @@ switch ($serendipity['GET']['adminAction']) {
             printf(ERROR_NO_DIRECTORY, $new_dir);
         }
 
+        serendipity_plugin_api::hook_event('backend_directory_delete', $new_dir);
+
         break;
 
     case 'directoryEdit':
@@ -497,9 +499,11 @@ switch ($serendipity['GET']['adminAction']) {
 
         $new_dir = serendipity_uploadSecure($serendipity['POST']['parent'] . '/' . $serendipity['POST']['name'], true);
         $new_dir = str_replace(array('..', '//'), array('', '/'), $new_dir);
+        $nd      = $serendipity['serendipityPath'] . $serendipity['uploadPath'] . $new_dir;
+        serendipity_plugin_api::hook_event('backend_directory_create', $nd);
 
         /* TODO: check if directory already exist */
-        if (@mkdir($serendipity['serendipityPath'] . $serendipity['uploadPath'] . $new_dir)) {
+        if (is_dir($nd) || @mkdir($nd)) {
             printf(DIRECTORY_CREATED, $serendipity['POST']['name']);
             @umask(0000);
             @chmod($serendipity['serendipityPath'] . $serendipity['uploadPath'] . $new_dir, 0777);
@@ -563,6 +567,7 @@ switch ($serendipity['GET']['adminAction']) {
                 </select>
             </td>
         </tr>
+        <?php serendipity_plugin_api::hook_event('backend_directory_createoptions', $folders); ?>
     </table>
     <div><input name="SAVE" value="<?php echo CREATE_DIRECTORY ?>" class="serendipityPrettyButton input_button" type="submit"></div>
     </form>
