@@ -1,4 +1,4 @@
-<?php # $Id: plugins.inc.php 1823 2007-08-07 13:59:43Z garvinhicking $
+<?php # $Id: plugins.inc.php 2039 2007-11-26 13:20:38Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -149,7 +149,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     $errorstack  = array_merge((array)$foreignPlugins['errorstack'], $errorstack);
 
     $plugins = serendipity_plugin_api::get_installed_plugins();
-    $classes = serendipity_plugin_api::enum_plugin_classes(($serendipity['GET']['type'] == 'event'));
+    $classes = serendipity_plugin_api::enum_plugin_classes(($serendipity['GET']['type'] === 'event'));
     usort($classes, 'serendipity_pluginListSort');
 
     $counter    = 0;
