@@ -1,4 +1,4 @@
-<?php # $Id: templates.inc.php 1816 2007-08-06 10:18:39Z garvinhicking $
+<?php # $Id: templates.inc.php 2258 2008-04-21 12:17:39Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -69,7 +69,7 @@ if (file_exists($serendipity['serendipityPath'] . $serendipity['templatePath'] .
 if (is_array($template_config)) {
     serendipity_plugin_api::hook_event('backend_templates_configuration_top', $template_config);
 
-    if ($serendipity['POST']['adminAction'] == 'configure') {
+    if ($serendipity['POST']['adminAction'] == 'configure' && serendipity_checkFormToken()) {
         foreach($serendipity['POST']['template'] AS $option => $value) {
             template_option::set_config($option, $value);
         }
@@ -77,6 +77,7 @@ if (is_array($template_config)) {
     }
 
     echo '<form method="post" action="serendipity_admin.php">';
+    echo serendipity_setformToken();
     echo '<input type="hidden" name="serendipity[adminModule]" value="templates" />';
     echo '<input type="hidden" name="serendipity[adminAction]" value="configure" />';
 
