@@ -1,4 +1,4 @@
-<?php # $Id: functions.inc.php 1721 2007-06-11 14:32:32Z garvinhicking $
+<?php # $Id: functions.inc.php 2213 2008-04-10 15:35:29Z donchambers $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -370,7 +370,7 @@ function serendipity_fetchUsers($user = '', $group = null, $is_count = false) {
     if ($is_count) {
         $query_select = ", count(e.authorid) as artcount";
         $query_join   = "LEFT OUTER JOIN {$serendipity['dbPrefix']}entries AS e
-                                      ON a.authorid = e.authorid";
+                                      ON (a.authorid = e.authorid AND e.isdraft = 'false')";
     }
 
     if ($is_count || $group != null) {
@@ -487,7 +487,7 @@ function serendipity_sendMail($to, $subject, $message, $fromMail, $headers = NUL
         'fromName' => &$fromName,
         'fromMail' => &$fromMail,
         'blogMail' => $serendipity['blogMail'],
-        'version'  => 'Serendipity/' . $serendipity['version'],
+        'version'  => 'Serendipity' . ($serendipity['expose_s9y'] ? '/' . $serendipity['version'] : ''),
         'legacy'   => true,
         'headers'  => &$headers,
         'message'  => &$message
@@ -513,8 +513,10 @@ function serendipity_sendMail($to, $subject, $message, $fromMail, $headers = NUL
             $maildata['headers'][] = 'From: "'. $maildata['fromName'] .'" <'. $maildata['blogMail'] .'>';
         }
         $maildata['headers'][] = 'Reply-To: "'. $maildata['fromName'] .'" <'. $maildata['fromMail'] .'>';
-        $maildata['headers'][] = 'X-Mailer: ' . $maildata['version'];
-        $maildata['headers'][] = 'X-Engine: PHP/'. phpversion();
+        if ($serendipity['expose_s9y']) {
+            $maildata['headers'][] = 'X-Mailer: ' . $maildata['version'];
+            $maildata['headers'][] = 'X-Engine: PHP/'. phpversion();
+        }
         $maildata['headers'][] = 'Message-ID: <'. md5(microtime() . uniqid(time())) .'@'. $_SERVER['HTTP_HOST'] .'>';
         $maildata['headers'][] = 'MIME-Version: 1.0';
         $maildata['headers'][] = 'Precedence: bulk';
@@ -666,9 +668,14 @@ function serendipity_fetchAuthor($author) {
  */
 function serendipity_parseFileName($file) {
     $x = explode('.', $file);
-    $suf = array_pop($x);
-    $f   = @implode('.', $x);
-    return array($f, $suf);
+    if (count($x)>1){
+        $suf = array_pop($x);
+        $f   = @implode('.', $x);
+        return array($f, $suf);
+    }
+    else {
+        return array($file,'');
+    }
 }
 
 /**
@@ -911,15 +918,15 @@ function serendipity_displayTopUrlList($list, $limit, $use_links = true, $interv
             if ($use_links) {
                 printf(
                     '<a href="%1$s://%2$s" title="%2$s" >%2$s</a> (%3$s)<br />',
-                    $row['scheme'],
-                    $row['host'],
-                    $row['total']
+                    htmlspecialchars($row['scheme']),
+                    htmlspecialchars($row['host']),
+                    htmlspecialchars($row['total'])
                 );
             } else {
                 printf(
                     '%1$s (%2$s)<br />',
-                    $row['host'],
-                    $row['total']
+                    htmlspecialchars($row['host']),
+                    htmlspecialchars($row['total'])
                 );
             }
         }
@@ -1144,6 +1151,12 @@ function &serendipity_pickKey(&$array, $key, $default) {
         return $default;
     }
 
+    // array_key_exists() copies array, so is much slower.
+    if (in_array($key, array_keys($array))) {
+        if (isset($array[$key])) {
+            return $array[$key];
+        }
+    }
     foreach($array AS $child) {
         if (is_array($child) && isset($child[$key]) && !empty($child[$key])) {
             return $child[$key];
