@@ -1,4 +1,4 @@
-<?php # $Id: functions_comments.inc.php 1779 2007-07-15 15:14:06Z garvinhicking $
+<?php # $Id: functions_comments.inc.php 2172 2008-03-17 08:58:32Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -135,6 +135,8 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
         $type = 'NORMAL';
     } elseif ($type == 'trackbacks') {
         $type = 'TRACKBACK';
+    } elseif ($type == 'pingbacks') {
+        $type = 'PINGBACK';
     } elseif ($type == 'comments_and_trackbacks') {
         $type = '%';
     }
@@ -179,10 +181,11 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
     $comments = serendipity_db_query($query, false, 'assoc');
 
     if (!is_array($comments)) {
-        return array();
+        $comments = array();
     }
 
-    serendipity_plugin_api::hook_event('fetchcomments', $comments);
+    $addData = array('id' => $id, 'limit' => $limit, 'order' => $order, 'showAll' => $showAll, 'type' => $type, 'where' => $where);
+    serendipity_plugin_api::hook_event('fetchcomments', $comments, $addData);
 
     return $comments;
 }
@@ -289,6 +292,9 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
             $comment['trace']   = $trace . $i;
             $comment['depth']   = $depth;
             $comment['author']  = htmlspecialchars($comment['author']);
+            if (isset($comment['title'])) {
+                $comment['title']   = htmlspecialchars($comment['title']);
+            }
 
             $_smartyComments[] = $comment;
             if ($comment['id'] && $parentid !== VIEWMODE_LINEAR ) {
@@ -302,7 +308,7 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
         return true;
     }
 
-    $serendipity['smarty']->assign_by_ref('comments', $_smartyComments);
+    $serendipity['smarty']->assign_by_ref($smarty_block == 'COMMENTS'?'comments':'trackbacks', $_smartyComments);
     unset($_smartyComments);
 
     return serendipity_smarty_fetch($smarty_block, $smarty_file);
@@ -495,9 +501,10 @@ function serendipity_allowCommentsToggle($entry_id, $switch = 'disable') {
  * @param   int         The ID of the comment to approve
  * @param   int         The ID of the entry a comment belongs to
  * @param   boolean     Whether to force approving a comment despite of its current status
+ * @param  boolean      If set to true, a comment will be moderated instead of approved.
  * @return boolean      Success or failure
  */
-function serendipity_approveComment($cid, $entry_id, $force = false) {
+function serendipity_approveComment($cid, $entry_id, $force = false, $moderate = false) {
     global $serendipity;
 
     /* Get data about the comment, we need this query because this function can be called from anywhere */
@@ -516,7 +523,11 @@ function serendipity_approveComment($cid, $entry_id, $force = false) {
         return false;
     }
 
-    $sql = "UPDATE {$serendipity['dbPrefix']}comments SET status = 'approved' WHERE id = ". (int)$cid;
+    if ($moderate) {
+        $sql = "UPDATE {$serendipity['dbPrefix']}comments SET status = 'pending' WHERE id = ". (int)$cid;
+    } else {
+        $sql = "UPDATE {$serendipity['dbPrefix']}comments SET status = 'approved' WHERE id = ". (int)$cid;
+    }
     serendipity_db_query($sql);
 
     $field = ($rs['type'] == 'NORMAL' ? 'comments' : 'trackbacks');
@@ -529,14 +540,21 @@ function serendipity_approveComment($cid, $entry_id, $force = false) {
         $lm = (int)$rs['entry_last_modified'];
     }
 
-    $query = "UPDATE {$serendipity['dbPrefix']}entries SET $field=$field+1, last_modified=". $lm ." WHERE id='". (int)$entry_id ."'";
+    if ($moderate) {
+        $query = "UPDATE {$serendipity['dbPrefix']}entries SET $field=$field-1, last_modified=". $lm ." WHERE id='". (int)$entry_id ."'";
+    } else {
+        $query = "UPDATE {$serendipity['dbPrefix']}entries SET $field=$field+1, last_modified=". $lm ." WHERE id='". (int)$entry_id ."'";
+    }
     serendipity_db_query($query);
 
-    if ($serendipity['allowSubscriptions']) {
-        serendipity_mailSubscribers($entry_id, $rs['author'], $rs['email'], $rs['title'], $rs['authoremail'], $cid);
+    if (!$moderate) {
+        if ($serendipity['allowSubscriptions']) {
+            serendipity_mailSubscribers($entry_id, $rs['author'], $rs['email'], $rs['title'], $rs['authoremail'], $cid);
+        }
+
+        serendipity_plugin_api::hook_event('backend_approvecomment', $rs);
     }
 
-    serendipity_plugin_api::hook_event('backend_approvecomment', $rs);
     return true;
 }
 
@@ -576,8 +594,12 @@ function serendipity_saveComment($id, $commentInfo, $type = 'NORMAL', $source =
                  FROM {$serendipity['dbPrefix']}entries e, {$serendipity['dbPrefix']}authors a
                  WHERE e.id  = '". (int)$id ."'
                    AND e.isdraft = 'false'
-                   AND e.timestamp <= " . time() . "
                    AND e.authorid = a.authorid";
+        if (!serendipity_db_bool($serendipity['showFutureEntries'])) {
+            $query .= " AND e.timestamp <= " . serendipity_db_time();
+
+        }
+
         $row = serendipity_db_query($query, true); // Get info on author/entry
         if (!is_array($row) || empty($id)) {
             // No associated entry found.
