@@ -1,4 +1,4 @@
-<?php # $Id: functions_config.inc.php 1860 2007-08-21 10:26:07Z garvinhicking $
+<?php # $Id: functions_config.inc.php 1975 2007-10-12 09:12:48Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -820,6 +820,9 @@ function serendipity_probeInstallation($item) {
             if (extension_loaded('SQLITE3')) {
                 $res['sqlite3'] = 'SQLite3';
             }
+            if (function_exists('sqlrcon_alloc')) {
+                $res['sqlrelay'] = 'SQLRelay';
+            }
             break;
 
         case 'rewrite' :
@@ -1993,6 +1996,7 @@ function &serendipity_loadThemeOptions(&$template_config, $okey = '') {
     return $template_vars;
 }
 
+
 /**
  * Check if a member of a group has permissions to execute a plugin
  *
