@@ -1,4 +1,4 @@
-<?php # $Id: functions_entries.inc.php 2062 2007-12-06 11:13:42Z garvinhicking $
+<?php # $Id: functions_entries.inc.php 2191 2008-03-20 09:17:25Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -204,9 +204,12 @@ function &serendipity_fetchEntryCategories($entryid) {
  * @param   string      Can contain a SQL statement on which keys to select. Plugins can also set this, pay attention!
  * @param   string      Can contain a SQL statement on how to group the query. Plugins can also set this, pay attention!
  * @param   string      If set to "array", the array of entries will be returned. "flat-array" will only return the articles without their entryproperties. "single" will only return a 1-dimensional array. "query" will only return the used SQL.
+ * @param   bool        Should an SQL-join be made to the AUTHORS DB table?
+ * @param   bool        Should an SQL-join be made to the CATEGORIES DB table?
+ * @param   string      SQL-Parts to add to JOIN
  * @return  array       Holds the super-array of all entries with all additional information
  */
-function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fetchDrafts = false, $modified_since = false, $orderby = 'timestamp DESC', $filter_sql = '', $noCache = false, $noSticky = false, $select_key = null, $group_by = null, $returncode = 'array') {
+function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fetchDrafts = false, $modified_since = false, $orderby = 'timestamp DESC', $filter_sql = '', $noCache = false, $noSticky = false, $select_key = null, $group_by = null, $returncode = 'array', $joinauthors = true, $joincategories = true, $joinown = null) {
     global $serendipity;
 
     $cond = array();
@@ -376,13 +379,27 @@ function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fe
     // Store the unique query condition for entries for later reference, like getting the total article count.
     $serendipity['fullCountQuery'] = "
                 FROM
-                    {$serendipity['dbPrefix']}entries AS e
+                    {$serendipity['dbPrefix']}entries AS e";
+    if ($joinauthors) {
+        $serendipity['fullCountQuery'] .= "
                     LEFT JOIN {$serendipity['dbPrefix']}authors a
-                        ON e.authorid = a.authorid
+                        ON e.authorid = a.authorid";
+    }
+
+    if ($joincategories || !isset($serendipity['enableACL']) || $serendipity['enableACL'] == true) {
+        // Category joins are REQUIRED when the ACLs are enabled.
+        $serendipity['fullCountQuery'] .= "
                     LEFT JOIN {$serendipity['dbPrefix']}entrycat ec
                         ON e.id = ec.entryid
                     LEFT JOIN {$serendipity['dbPrefix']}category c
-                        ON ec.categoryid = c.categoryid
+                        ON ec.categoryid = c.categoryid";
+    }
+    
+    if ($joinown) {
+        $cond['joins'] .= $joinown;
+    }
+
+    $serendipity['fullCountQuery'] .="
                     {$cond['joins']}
                     {$cond['and']}";
 
@@ -518,7 +535,7 @@ function &serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false
                         ON  e.authorid = a.authorid
                             {$cond['joins']}
                      WHERE
-                            e.$key LIKE '" . serendipity_db_escape_string($val) . "'
+                            e.$key " . ($key == 'id' ? '=' : 'LIKE') . " '" . serendipity_db_escape_string($val) . "'
                             {$cond['and']}
                      LIMIT  1";
 
@@ -801,7 +818,14 @@ function serendipity_printEntryFooter($suffix = '.html', $totalEntries = null) {
     if ($totalEntries === null) {
         $totalEntries = serendipity_getTotalEntries();
     }
-    $totalPages   = ceil($totalEntries / $serendipity['fetchLimit']);
+    
+    $limits = explode(',', $serendipity['fetchLimit']);
+    if (!empty($limits[1])) {
+        $limit = (int)$limits[1];
+    } else {
+        $limit = (int)$limits[0];
+    }
+    $totalPages   = ceil($totalEntries / $limit);
 
     if (!isset($serendipity['GET']['page'])) {
         $serendipity['GET']['page'] = 1;
@@ -983,6 +1007,8 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
                 $entry['authorid'] = $serendipity['authorid'];
             }
 
+            $entry['author'] = htmlspecialchars($entry['author']);
+
             $authorData = array(
                             'authorid' => $entry['authorid'],
                             'username' => $entry['loginname'],
