@@ -1,4 +1,4 @@
-<?php # $Id: functions_smarty.inc.php 1860 2007-08-21 10:26:07Z garvinhicking $
+<?php # $Id: functions_smarty.inc.php 2189 2008-03-19 11:34:22Z slothman $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -27,7 +27,7 @@ function &serendipity_fetchTrackbacks($id, $limit = null, $showAll = false) {
         $and = "AND status = 'approved'";
     }
 
-    $query = "SELECT * FROM {$serendipity['dbPrefix']}comments WHERE entry_id = '". (int)$id ."' AND type = 'TRACKBACK' $and ORDER BY id";
+    $query = "SELECT * FROM {$serendipity['dbPrefix']}comments WHERE entry_id = '". (int)$id ."' AND (type = 'TRACKBACK' OR type = 'PINGBACK') $and ORDER BY id";
     if (isset($limit)) {
         $limit  = serendipity_db_limit_sql($limit);
         $query .= " $limit";
@@ -141,6 +141,13 @@ function serendipity_ifRemember($name, $value, $isDefault = false, $att = 'check
  *                          filter_sql       (string)  Can contain any SQL code to inject into the central SQL statement for fetching the entry
  *                          noCache          (boolean) If set to TRUE, all entries will be fetched from scratch and any caching is ignored
  *                          noSticky         (boolean) If set to TRUE, all sticky entries will NOT be fetched.
+ *                          select_key       (string)  Can contain a SQL statement on which keys to select. Plugins can also set this, pay attention!
+ *                          group_by         (string)  Can contain a SQL statement on how to group the query. Plugins can also set this, pay attention!
+ *                          returncode       (string)  If set to "array", the array of entries will be returned. "flat-array" will only return the articles without their entryproperties. "single" will only return a 1-dimensional array. "query" will only return the used SQL.
+ *                          joinauthors      (bool)    Should an SQL-join be made to the AUTHORS DB table?
+ *                          joincategories   (bool)    Should an SQL-join be made to the CATEGORIES DB table?
+ *                          joinown          (string)  SQL-Parts to add to the "JOIN" query
+ *                          entryprops       (string)  Condition list of commaseparated entryproperties that an entry must have to be displayed (example: "ep_CustomField='customVal',ep_CustomField2='customVal2'")
  *
  *                      [PRINTING]
  *                          template:          (string)  Name of the template file to print entries with
@@ -179,6 +186,18 @@ function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
     if (empty($params['fetchDrafts'])) {
         $params['fetchDrafts'] = false;
     }
+    
+    if (!empty($params['entryprops'])) {
+        if (preg_match_all('@(.*)(!)?=[\'"]*(.*)[\'"]*(,|$)@imsU', $params['entryprops'], $m)) {
+            foreach($m[0] AS $idx => $p) {
+                $params['joinown'] .= "\n JOIN {$serendipity['dbPrefix']}entryproperties 
+                                          AS ep" . $idx . " 
+                                          ON (ep" . $idx . ".entryid = e.id AND 
+                                              ep" . $idx . ".property = '" . serendipity_db_escape_string($m[1][$idx]) . "' AND 
+                                              ep" . $idx . ".value " . $m[2][$idx] . "= '" . serendipity_db_escape_string($m[3][$idx]) . "') \n";
+            }
+        }
+    }
 
     if (empty($params['modified_since'])) {
         $params['modified_since'] = false;
@@ -228,6 +247,26 @@ function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
         $params['prevent_reset'] = false;
     }
 
+    if (empty($params['select_key'])) {
+        $params['select_key'] = null;
+    }
+
+    if (empty($params['group_by'])) {
+        $params['group_by'] = null;
+    }
+
+    if (empty($params['returncode'])) {
+        $params['returncode'] = 'array';
+    }
+
+    if (empty($params['joinauthors'])) {
+        $params['joinauthors'] = true;
+    }
+
+    if (empty($params['joincategories'])) {
+        $params['joincategories'] = true;
+    }
+
     // Some functions deal with the $serendipity array. To modify them, we need to store
     // their original contents.
     $old_var = array();
@@ -265,7 +304,13 @@ function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
             $params['orderby'],
             $params['filter_sql'],
             $params['noCache'],
-            $params['noSticky']
+            $params['noSticky'],
+            $params['select_key'],
+            $params['group_by'],
+            $params['returncode'],
+            $params['joinauthors'],
+            $params['joincategories'],
+            $params['joinown']
         );
 
         // Check whether the returned entries shall be grouped specifically
@@ -547,7 +592,12 @@ function serendipity_smarty_printSidebar($params, &$smarty) {
         $smarty->trigger_error(__FUNCTION__ .": missing 'side' parameter");
         return;
     }
-    return serendipity_plugin_api::generate_plugins($params['side']);
+
+    if (isset($params['template'])) {
+        return serendipity_plugin_api::generate_plugins($params['side'], '', false, null, null, $params['template']);
+    } else {
+        return serendipity_plugin_api::generate_plugins($params['side']);
+    }
 }
 
 /**
@@ -699,8 +749,50 @@ function &serendipity_smarty_printTrackbacks($params, &$smarty) {
         return;
     }
 
-    $tb =& serendipity_fetchTrackbacks($params['entry']);
-    return serendipity_printTrackbacks($tb);
+    $trackbacks =& serendipity_fetchTrackbacks($params['entry']);
+
+    $out = serendipity_printComments($trackbacks, VIEWMODE_LINEAR, 0, null, 'TRACKBACKS', 'trackbacks.tpl');
+    return $out;
+}
+
+/**
+ * Get the Serendipity dimensions for an image
+ *
+ * @access public
+ * @param   array       Smarty parameter input array:
+ *                      file: The image file to get image data for
+ *                      assign: The variable to assign the image data array to
+ * @param   object      Smarty object
+ * @return  string      Empty
+ */
+function serendipity_smarty_getImageSize($params, &$smarty) {
+    global $serendipity;
+
+    if (!isset($params['file'])) {
+        $smarty->trigger_error(__FUNCTION__ .": missing 'file' parameter");
+        return;
+    } 
+    if (!isset($params['assign'])) {
+        $smarty->trigger_error(__FUNCTION__ .": missing 'assign' parameter");
+        return;
+    }
+
+    // Is it a correct filesystem absolute path?
+    $file = $params['file'];
+    // Most likely the user specified an HTTP path
+    if (!file_exists($file)) {
+      $file = $_SERVER['DOCUMENT_ROOT'] . $file;
+    }
+    // Maybe wants a template file (returns filesystem path)
+    if (!file_exists($file)) {
+      $file = serendipity_getTemplateFile($params['file']);
+    }
+    // If no file, trigger an error
+    if (!file_exists($file)) {
+      $smarty->trigger_error(__FUNCTION__ .': file ' . $params['file'] . NOT_FOUND . ' ');
+      return;
+    }
+    $smarty->assign($params['assign'], serendipity_getimagesize($file));
 }
 
 /**
@@ -795,6 +887,7 @@ function serendipity_smarty_init($vars = array()) {
             $serendipity['smarty']->register_function('serendipity_getTotalCount', 'serendipity_smarty_getTotalCount');
             $serendipity['smarty']->register_function('pickKey', 'serendipity_smarty_pickKey');
             $serendipity['smarty']->register_function('serendipity_showCommentForm', 'serendipity_smarty_showCommentForm');
+            $serendipity['smarty']->register_function('serendipity_getImageSize', 'serendipity_smarty_getImageSize');
             $serendipity['smarty']->register_prefilter('serendipity_replaceSmartyVars');
         }
 
