@@ -1,4 +1,4 @@
-<?php # $Id: functions_upgrader.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: functions_upgrader.inc.php 1696 2007-05-18 07:59:14Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -46,7 +46,9 @@ $obsolete_files = array(
     'serendipity_db_mysql.inc.php',
     'serendipity_db_mysqli.inc.php',
     'serendipity_db_postgres.inc.php',
+    'serendipity_db_pdo-postgres.inc.php',
     'serendipity_db_sqlite.inc.php',
+    'serendipity_db_sqlite3.inc.php',
     'htaccess.cgi.errordocs.tpl',
     'htaccess.cgi.normal.tpl',
     'htaccess.cgi.rewrite.tpl',
