@@ -1,4 +1,4 @@
-<?php # $Id: index.php 1732 2007-06-18 11:57:15Z garvinhicking $
+<?php # $Id: index.php 2098 2008-01-29 19:11:04Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -97,23 +97,23 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $_args = $serendipity['uriArguments'];
 
     /* Attempt to locate hidden variables within the URI */
-    foreach ($_args as $k => $v){
+    foreach ($_args AS $k => $v){
         if ($v == PATH_ARCHIVES) {
             continue;
         }
-        if ($v{0} == 'C') { /* category */
+        if ($v[0] == 'C') { /* category */
             $cat = substr($v, 1);
             if (is_numeric($cat)) {
                 $serendipity['GET']['category'] = $cat;
                 unset($_args[$k]);
             }
-        } elseif ($v{0} == 'A') { /* Author */
+        } elseif ($v[0] == 'A') { /* Author */
             $url_author = substr($v, 1);
             if (is_numeric($url_author)) {
                 $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
                 unset($_args[$k]);
             }
-        } elseif ($v{0} == 'W') { /* Week */
+        } elseif ($v[0] == 'W') { /* Week */
             $week = substr($v, 1);
             if (is_numeric($week)) {
                 unset($_args[$k]);
@@ -121,7 +121,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         } elseif ($v == 'summary') { /* Summary */
             $serendipity['short_archives'] = true;
             unset($_args[$k]);
-        } elseif ($v{0} == 'P') { /* Page */
+        } elseif ($v[0] == 'P') { /* Page */
             $page = substr($v, 1);
             if (is_numeric($page)) {
                 $serendipity['GET']['page'] = $page;
@@ -250,10 +250,18 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 
     echo $data;
 } else if ( preg_match(PAT_COMMENTSUB, $uri, $matches) ||
-            preg_match(PAT_PERMALINK, $uri, $matches) ) {
+            preg_match(PAT_PERMALINK, $uri, $matches) ||
+            isset($serendipity['GET']['id']) ||
+            isset($_GET['p']) ) {
     $serendipity['view'] = 'entry';
 
-    $matches[1] = serendipity_searchPermalink($serendipity['permalinkStructure'], $uri, (!empty($matches[2]) ? $matches[2] : $matches[1]), 'entry');
+    if (isset($serendipity['GET']['id'])) {
+        $matches[1] = (int)$serendipity['GET']['id'];
+    } elseif (isset($_GET['p'])) {
+        $matches[1] = $_GET['p'];
+    } else {
+        $matches[1] = serendipity_searchPermalink($serendipity['permalinkStructure'], $uri, (!empty($matches[2]) ? $matches[2] : $matches[1]), 'entry');
+    }
     serendipity_rememberComment();
 
     if (!empty($serendipity['POST']['submit']) && !isset($_REQUEST['serendipity']['csuccess'])) {
@@ -279,6 +287,9 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     }
 
     $id = (int)$matches[1];
+    if ($id === 0) {
+        $id = false;
+    }
 
     serendipity_track_referrer($id);
     $track_referer = false;
@@ -358,18 +369,18 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $serendipity['GET']['action'] = 'archives';
     $_args = $serendipity['uriArguments'];
     /* Attempt to locate hidden variables within the URI */
-    foreach ($_args as $k => $v){
+    foreach ($_args AS $k => $v){
         if ($v == PATH_ARCHIVE) {
             continue;
         }
 
-        if ($v{0} == 'C') { /* category */
+        if ($v[0] == 'C') { /* category */
             $cat = substr($v, 1);
             if (is_numeric($cat)) {
                 $serendipity['GET']['category'] = $cat;
                 unset($_args[$k]);
             }
-        } elseif ($v{0} == 'A') { /* Author */
+        } elseif ($v[0] == 'A') { /* Author */
             $url_author = substr($v, 1);
             if (is_numeric($url_author)) {
                 $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
@@ -393,8 +404,10 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         $serendipity['uriArguments'][]  = PATH_CATEGORIES;
         $serendipity['uriArguments'][]  = serendipity_db_escape_string($serendipity['GET']['category']) . '-multi';
     } elseif (preg_match('@/([0-9;]+)@', $uri, $multimatch)) {
-        $is_multicat = true;
-        $serendipity['GET']['category'] = $multimatch[1];
+        if (stristr($multimatch[1], ';')) {
+            $is_multicat = true;
+            $serendipity['GET']['category'] = $multimatch[1];
+        }
     }
 
     $serendipity['GET']['action'] = 'read';
@@ -402,18 +415,18 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $_args = $serendipity['uriArguments'];
 
     /* Attempt to locate hidden variables within the URI */
-    foreach ($_args as $k => $v) {
+    foreach ($_args AS $k => $v) {
         if ($v == PATH_CATEGORIES) {
             continue;
         }
-        if ($v{0} == 'P') { /* Page */
+        if ($v[0] == 'P') { /* Page */
             $page = substr($v, 1);
             if (is_numeric($page)) {
                 $serendipity['GET']['page'] = $page;
                 unset($_args[$k]);
                 unset($serendipity['uriArguments'][$k]);
             }
-        } elseif ($v{0} == 'A') { /* Author */
+        } elseif ($v[0] == 'A') { /* Author */
             $url_author = substr($v, 1);
             if (is_numeric($url_author)) {
                 $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)$url_author;
@@ -455,8 +468,8 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $_args = $serendipity['uriArguments'];
 
     /* Attempt to locate hidden variables within the URI */
-    foreach ($_args as $k => $v){
-        if ($v{0} == 'P') { /* Page */
+    foreach ($_args AS $k => $v){
+        if ($v[0] == 'P') { /* Page */
             $page = substr($v, 1);
             if (is_numeric($page)) {
                 $serendipity['GET']['page'] = $page;
@@ -489,12 +502,12 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 
     /* Attempt to locate hidden variables within the URI */
     $search = array();
-    foreach ($_args as $k => $v){
+    foreach ($_args AS $k => $v){
         if ($v == PATH_SEARCH) {
             continue;
         }
 
-        if ($v{0} == 'P') { /* Page */
+        if ($v[0] == 'P') { /* Page */
             $page = substr($v, 1);
             if (is_numeric($page)) {
                 $serendipity['GET']['page'] = $page;
@@ -523,12 +536,12 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 
     /* Attempt to locate hidden variables within the URI */
     $search = array();
-    foreach ($_args as $k => $v){
+    foreach ($_args AS $k => $v){
         if ($v == PATH_COMMENTS) {
             continue;
         }
 
-        if ($v{0} == 'P') { /* Page */
+        if ($v[0] == 'P') { /* Page */
             $page = substr($v, 1);
             if (is_numeric($page)) {
                 $serendipity['GET']['page'] = $page;
