@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_zh.inc.php 1907 2007-09-10 10:42:31Z brockhaus $
+<?php # $Id: serendipity_lang_zh.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by
@@ -897,3 +897,6 @@
 @define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('SET_TO_MODERATED', 'Moderate');
+@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
+@define('CENTER', 'center');
