@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_bg.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
+<?php # $Id: serendipity_lang_bg.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
@@ -886,4 +886,7 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('PINGBACK_FAILED', ' pingback: %s');
 @define('PINGBACK_NOT_FOUND', '   pingback-URI.');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', '    ,         (   )');
-@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS ,   PHP5       ');
+@define('SET_TO_MODERATED', '');
+@define('COMMENT_MODERATED', ' #%s     ');
+@define('CENTER', '');
