@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_de.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
+<?php # $Id: serendipity_lang_de.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Jannis Hermanns, Garvin Hicking and others
@@ -887,9 +887,13 @@
 @define('USERCONF_CREATE_DESC', 'Wenn diese Option aktiviert ist, wird dieser Benutzer keine Mglichkeit mehr haben Eintrge anzulegen oder sonstige Aktionen auszufhren. Wenn er in die Administrations-Oberflche kommt, wird er nichts anderes tun knnen als seine Persnlichen Einstellungen zu ndern und sich auszuloggen.');
 @define('CATEGORY_HIDE_SUB', 'Artikel von Unterkategorien verstecken?');
 @define('CATEGORY_HIDE_SUB_DESC', 'Standardmig werden bei der Ansicht einer Kategorie im Frontend alle Artikel der gewhlten Kategorie und aller Unterkategorien angezeigt. Wenn diese Option aktiviert wird, werden Artikel von Unterkategorien nicht angezeigt.');
-@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
-@define('PINGBACK_SENT', 'Pingback successful');
-@define('PINGBACK_FAILED', 'Pingback failed: %s');
-@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
+@define('PINGBACK_SENDING', 'Sende pingback an URI %s...');
+@define('PINGBACK_SENT', 'Pingback erfolgreich');
+@define('PINGBACK_FAILED', 'Pingback fehlgeschlagen: %s');
+@define('PINGBACK_NOT_FOUND', 'Keine pingback-URI gefunden.');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+
+@define('SET_TO_MODERATED', 'Moderieren');
+@define('COMMENT_MODERATED', 'Kommentar #%s wurde erfolgreich moderiert.');
+@define('CENTER', 'mitte');
