@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tn.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
+<?php # $Id: serendipity_lang_tn.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -900,3 +900,6 @@ $i18n_unknown = 'tw';
 @define('PINGBACK_NOT_FOUND', '沒有回測的網頁。');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', '隱藏歷史的連接如果時間內沒有文章 (需要計算文章數)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('SET_TO_MODERATED', 'Moderate');
+@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
+@define('CENTER', 'center');
