@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 2054 2007-12-06 09:26:35Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -901,3 +901,6 @@ $i18n_unknown = 'tw';
 @define('PINGBACK_NOT_FOUND', 'S^C');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'þvspGɶS峹 (ݭnp峹)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('SET_TO_MODERATED', 'Moderate');
+@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
+@define('CENTER', 'center');
