@@ -1,8 +1,9 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 2044 2007-12-01 08:46:08Z jwalker $
 
 /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 2044 $
  *  @author Ivan Cenov jwalker@hotmail.bg
+*  EN-Revision: 2030
  */
 
     @define('PLUGIN_EVENT_MAILER_NAME', '    e-mail');
@@ -19,3 +20,4 @@
     @define('PLUGIN_EVENT_MAILER_NOTSENDDECISION', '     e-mail,     .');
     @define('PLUGIN_EVENT_MAILER_SENDING', '');
     @define('PLUGIN_EVENT_MAILER_ISTOSENDIT', '     e-mail');
+    @define('PLUGIN_EVENT_MAILER_SENDTOALL', '   ');
