@@ -1,6 +1,6 @@
-<?php # $Id: lang_es.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_es.inc.php 1561 2007-01-02 10:15:53Z garvinhicking $
 /**
- *  @version $Revision: 1381 $
+ *  @version $Revision: 1561 $
  *  @author Rodrigo Lazo Paz <rlazo.paz@gmail.com>
  *  EN-Revision: 690
  */
@@ -65,11 +65,12 @@
 @define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE_DESC', 'Busca comentarios con ciertas palabras y los marca como spam.');
 
 @define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS', 'Filtro por palabras para URLs');
-@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).');
+@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).  Escribe las arrobas (@) por \\@.');
 @define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS', 'Filtro por palabras para nombres de autor');
-@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).');
+@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC);
 
 @define('PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS', 'Filtrado por palabras para el cuerpo del comentario');
+@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS', 'Filtrado por palabras para el correo electrnico');
 
 @define('PLUGIN_EVENT_SPAMBLOCK_REASON_CHECKMAIL', 'Direccin e-mail invlida');
 @define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL', 'Revisar direccin e-mail?');
@@ -80,8 +81,10 @@
 @define('PLUGIN_EVENT_SPAMBLOCK_CONFIG', 'Configura los mtodos Anti-Spam');
 @define('PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR', 'Bloquear este autor a travs de la extensin Spamblock');
 @define('PLUGIN_EVENT_SPAMBLOCK_ADD_URL', 'Bloquear esta URL a travs de la extensin Spamblock');
+@define('PLUGIN_EVENT_SPAMBLOCK_ADD_EMAIL', 'Bloquear este correo electrnico a travs de la extensin Spamblock');
 @define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR', 'Desbloquear este autor a travs de la extensin Spamblock');
 @define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL', 'Desbloquear estea URL a travs de la extensin Spamblock');
+@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_EMAIL', 'Desbloquear este correo electrnico a travs de la extensin Spamblock');
 
 @define('PLUGIN_EVENT_SPAMBLOCK_BLOGG_SPAMLIST', 'Activar el filtrado de URL atravs de la lista negra blogg.de');
 @define('PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST', 'Filtrado a travs de la lista negra blogg.de');
