@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spartacus.php 2038 2007-11-26 13:20:34Z garvinhicking $
+<?php # $Id: serendipity_event_spartacus.php 2070 2007-12-11 10:33:57Z garvinhicking $
 
 /************
   TODO:
@@ -39,7 +39,7 @@ class serendipity_event_spartacus extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_SPARTACUS_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Garvin Hicking');
-        $propbag->add('version',       '2.14');
+        $propbag->add('version',       '2.15');
         $propbag->add('requirements',  array(
             'serendipity' => '0.9',
             'smarty'      => '2.6.7',
@@ -53,10 +53,15 @@ class serendipity_event_spartacus extends serendipity_event
             'backend_templates_fetchtemplate'    => true,
 
             'backend_pluginlisting_header'         => true,
-            'backend_pluginlisting_header_upgrade' => true
+            'backend_pluginlisting_header_upgrade' => true,
+            
+            'external_plugin'                      => true,
+
+            'backend_directory_create'             => true
         ));
         $propbag->add('groups', array('BACKEND_FEATURES'));
-        $propbag->add('configuration', array('enable_plugins', 'enable_themes', 'mirror_xml', 'mirror_files', 'chown', 'chmod_files', 'chmod_dir'));
+        $propbag->add('configuration', array('enable_plugins', 'enable_themes', 'enable_remote', 'remote_url', 'mirror_xml', 'mirror_files', 'chown', 'chmod_files', 'chmod_dir', 'use_ftp', 'ftp_server', 'ftp_username', 'ftp_password', 'ftp_basedir'));
+
     }
 
     function generate_content(&$title) {
@@ -144,6 +149,20 @@ class serendipity_event_spartacus extends serendipity_event
                 $propbag->add('default',     'true');
                 break;
 
+            case 'enable_remote':
+                $propbag->add('type',        'boolean');
+                $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_ENABLE_REMOTE);
+                $propbag->add('description', sprintf(PLUGIN_EVENT_SPARTACUS_ENABLE_REMOTE_DESC, $serendipity['baseURL'] . $serendipity['indexFile'] . '?/plugin/' . $this->get_config('remote_url')));
+                $propbag->add('default',     'false');
+                break;
+
+            case 'remote_url':
+                $propbag->add('type',        'string');
+                $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_ENABLE_REMOTE_URL);
+                $propbag->add('description', PLUGIN_EVENT_SPARTACUS_ENABLE_REMOTE_URL_DESC);
+                $propbag->add('default',     'spartacus_remote');
+                break;
+
             case 'chmod_files':
                 $propbag->add('type',        'string');
                 $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_CHMOD);
@@ -181,6 +200,55 @@ class serendipity_event_spartacus extends serendipity_event
                 $propbag->add('default',     0);
                 break;
 
+            case 'use_ftp':
+                if (function_exists('ftp_connect')) {
+                    $propbag->add('type',        'boolean');
+                    $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_FTP_USE);
+                    $propbag->add('description', PLUGIN_EVENT_SPARTACUS_FTP_USE_DESC);
+                    if (@ini_get('safe_mode')) {
+                        $propbag->add('default', 'true');
+                    } else {
+                        $propbag->add('default', 'false');
+                    }
+                }
+                break;
+                
+            case 'ftp_server':
+                if (function_exists('ftp_connect')) {
+                    $propbag->add('type',        'string');
+                    $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_FTP_SERVER);
+                    $propbag->add('description', '');
+                    $propbag->add('default',     '');
+                }
+                break;
+            
+            case 'ftp_username':
+                if (function_exists('ftp_connect')) {
+                    $propbag->add('type',        'string');
+                    $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_FTP_USERNAME);
+                    $propbag->add('description', '');
+                    $propbag->add('default',     '');
+                }
+                break;
+            
+            case 'ftp_password':
+                if (function_exists('ftp_connect')) {
+                    $propbag->add('type',        'string');
+                    $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_FTP_PASS);
+                    $propbag->add('description', '');
+                    $propbag->add('default',     '');
+                }
+                break;
+            
+            case 'ftp_basedir':
+                if (function_exists('ftp_connect')) {
+                    $propbag->add('type',        'string');
+                    $propbag->add('name',        PLUGIN_EVENT_SPARTACUS_FTP_BASEDIR);
+                    $propbag->add('description', PLUGIN_EVENT_SPARTACUS_FTP_BASEDIR_DESC);
+                    $propbag->add('default',     $serendipity['serendipityHTTPPath']);
+                }
+                break;
+
             default:
                 return false;
         }
@@ -224,6 +292,10 @@ class serendipity_event_spartacus extends serendipity_event
     function rmkdir($dir, $sub = 'plugins') {
         global $serendipity;
 
+        if (serendipity_db_bool($this->get_config('use_ftp')) && $this->get_config('ftp_password') != '') {
+            return $this->make_dir_via_ftp($dir);
+        }
+        
         $spaths = explode('/', $serendipity['serendipityPath'] . $sub . '/');
         $paths  = explode('/', $dir);
 
@@ -832,7 +904,7 @@ class serendipity_event_spartacus extends serendipity_event
         foreach($files AS $file) {
             $url    = $mirror . '/' . $sfloc . '/' . $file . '?rev=1.9999';
             $target = $pdir . $file;
-            @mkdir($pdir . $plugin_to_install);
+            $this->rmkdir($pdir . $plugin_to_install,$sub);
             $this->fileperm($pdir . $plugin_to_install, true);
             $this->fetchfile($url, $target);
             if (!isset($baseDir)) {
@@ -846,6 +918,58 @@ class serendipity_event_spartacus extends serendipity_event
         }
     }
 
+    function make_dir_via_ftp($dir) {
+        global $serendipity;
+        
+        if (!serendipity_db_bool($this->get_config('use_ftp'))) {
+            return false;
+        }
+        
+    	$ftp_server    = $this->get_config('ftp_server');
+    	$ftp_user_name = $this->get_config('ftp_username');
+    	$ftp_user_pass = $this->get_config('ftp_password');
+    	$basedir       = $this->get_config('ftp_basedir');
+    	$dir_rules     = intval($this->get_config('chmod_dir'), 8);
+
+        if (empty($ftp_server) || empty($ftp_user_name)) {
+            return false;
+        }
+
+    	$dir = str_replace($serendipity['serendipityPath'],"",$dir);
+    
+    	// set up basic connection and log in with username and password
+    	$conn_id       = ftp_connect($ftp_server); 
+    	$login_result  = ftp_login($conn_id, $ftp_user_name, $ftp_user_pass); 
+    
+    	// check connection
+    	if ((!$conn_id) || (!$login_result)) { 
+        	$this->outputMSG('error',PLUGIN_EVENT_SPARTACUS_FTP_ERROR_CONNECT);
+        	return false;
+        } else {
+        	$paths  = preg_split('@/@', $basedir.$dir,-1,PREG_SPLIT_NO_EMPTY);
+        	foreach ($paths as $path) {
+        	    // trying to change directory, if not succesfull, it means
+                // the directory does not exist and we must create it 
+        		if (!ftp_chdir($conn_id,$path)) {
+        			if (!ftp_mkdir($conn_id,$path)) {
+                        $this->outputMSG('error',PLUGIN_EVENT_SPARTACUS_FTP_ERROR_MKDIR);
+                        return false;
+                    }
+        			if (!ftp_chmod($conn_id,$dir_rules,$path)) {
+                        $this->outputMSG('error',PLUGIN_EVENT_SPARTACUS_FTP_ERROR_CHMOD);
+                        return false;
+                    }
+        			if (!ftp_chdir($conn_id,$path)) {
+                        return false;
+                    }
+      		        $this->outputMSG('success',sprintf(PLUGIN_EVENT_SPARTACUS_FTP_SUCCESS, $path));
+        		}
+        	}
+        	ftp_close($conn_id);
+        	return true;        
+    	}
+    }
+
     function event_hook($event, &$bag, &$eventData) {
         global $serendipity;
 
@@ -853,6 +977,65 @@ class serendipity_event_spartacus extends serendipity_event
 
         if (isset($hooks[$event])) {
             switch($event) {
+                case 'external_plugin':
+                    if (!serendipity_db_bool($this->get_config('enable_remote'))) {
+                        return false;
+                    }
+
+                    if ($eventData == $this->get_config('remote_url')) {
+                        header('Content-Type: text/plain');
+                        $avail   = array();
+                        $install = array();
+                        $meth    = array('event', 'sidebar');
+                        $active  = serendipity_plugin_api::get_installed_plugins();
+
+                        $avail['event']   = $this->buildList($this->fetchOnline('event'), 'event');
+                        $avail['sidebar'] = $this->buildList($this->fetchOnline('sidebar'), 'sidebar');
+                        
+                        $install['event']   = serendipity_plugin_api::enum_plugin_classes(true);
+                        $install['sidebar'] = serendipity_plugin_api::enum_plugin_classes(false);
+                        
+                        foreach($meth AS $method) {
+                            echo "LISTING: $method\n-------------------\n";
+                            foreach ($install[$method] as $class_data) {
+                                $pluginFile = serendipity_plugin_api::probePlugin($class_data['name'], $class_data['classname'], $class_data['pluginPath']);
+                                $plugin     = serendipity_plugin_api::getPluginInfo($pluginFile, $class_data, $method);
+                        
+                                if (is_object($plugin)) {
+                                    // Object is returned when a plugin could not be cached.
+                                    $bag = new serendipity_property_bag;
+                                    $plugin->introspect($bag);
+                        
+                                    // If a foreign plugin is upgradable, keep the new version number.
+                                    if (isset($avail[$method][$class_data['name']]) && $avail[$method][$class_data['name']]['upgradable']) {
+                                        $class_data['upgrade_version'] = $avail[$method][$class_data['name']]['upgrade_version'];
+                                    }
+                                    $props = serendipity_plugin_api::setPluginInfo($plugin, $pluginFile, $bag, $class_data, 'local', $avail[$method]);
+                                    
+                                } elseif (is_array($plugin)) {
+                                    // Array is returned if a plugin could be fetched from info cache
+                                    $props = $plugin;
+                                } else {
+                                    $props = false;
+                                }
+                        
+                                if (is_array($props)) {
+                                    #print_r($props);
+                                    if (version_compare($props['version'], $props['upgrade_version'], '<')) {
+                                        echo "UPGRADE: " . $class_data['name'] . " -- " . $props['upgrade_version'] . "\n";
+                                    } else {
+                                        echo "OK: " . $class_data['name'] . " -- " . $props['version'] . "\n";
+                                    }
+                                } else {
+                                    echo "ERROR: " . $class_data['true_name'] . "\n";
+                                }
+                            }
+                        }
+                    }
+
+                    return true;
+                    break;
+
                 case 'backend_pluginlisting_header':
                     if (serendipity_db_bool($this->get_config('enable_plugins'))) {
                         echo '<br /><div id="upgrade_notice" class="serendipityAdminMsgSuccess">';
@@ -929,6 +1112,14 @@ class serendipity_event_spartacus extends serendipity_event
                     return false;
                     break;
 
+                case 'backend_directory_create' :  
+                    if (serendipity_db_bool($this->get_config('use_ftp')) && (!is_dir($eventData))) {
+                        return $this->make_dir_via_ftp($eventData);
+                    }
+                
+                    return true;
+                    break;
+
                 default:
                     return false;
                     break;
