@@ -1,12 +1,12 @@
-<?php # $Id: lang_es.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_es.inc.php 2093 2008-01-18 12:50:00Z garvinhicking $
 /**
- *  @version $Revision: 1381 $
+ *  @version $Revision: 2093 $
  *  @author Rodrigo Lazo Paz <rlazo.paz@gmail.com>
  *  EN-Revision: 690
  */
 
 @define('PLUGIN_EVENT_TEXTILE_NAME', 'Formato: Textile');
 @define('PLUGIN_EVENT_TEXTILE_DESC', 'Analizar la salida a través del convertidor Textile');
-@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', 'Formato <a href="http://www.textism.com/tools/textile/">Textile</a> permitido');
+@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', 'Formato <a href="%s">Textile</a> permitido');
 
 ?>
