@@ -14,7 +14,7 @@
 
 @define('PLUGIN_EVENT_TEXTILE_NAME', 'Código: Textile');
 @define('PLUGIN_EVENT_TEXTILE_DESC', 'Filtra o texto das entradas através do conversor Textile');
-@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', 'Síntaxe <a href="http://www.textism.com/tools/textile/">Textile</a> autorizada');
+@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', 'Síntaxe <a href="%s">Textile</a> autorizada');
 
 /* vim: set sts=4 ts=4 expandtab : */
 ?>
\ No newline at end of file
