@@ -1,13 +1,10 @@
-<?php # $Id: lang_bg.inc.php 866 2006-01-23 15:10:01Z garvinhicking $
+<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
 
 /**
- *  @version $Revision: 866 $
- *  @author Ivan Cenov jwalker@abv.bg
- *  EN-Revision: 690
+ *  @version $Revision: 1419 $
+ *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
     @define('PLUGIN_EVENT_TEXTWIKI_NAME',     'Форматиране на текст: Wiki');
     @define('PLUGIN_EVENT_TEXTWIKI_DESC',     'Форматиране на текст чрез Text_Wiki конвертор');
     @define('PLUGIN_EVENT_TEXTWIKI_TRANSFORM', 'Форматиране <a href="http://c2.com/cgi/wiki">Wiki</a> е разрешено');
-
-?>
