@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_trackexits.php 1528 2006-12-01 08:58:47Z garvinhicking $
+<?php # $Id: serendipity_event_trackexits.php 1695 2007-05-16 14:12:45Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -26,7 +26,7 @@ class serendipity_event_trackexits extends serendipity_event
         $propbag->add('description',   PLUGIN_EVENT_TRACKBACK_DESC);
         $propbag->add('stackable',     false);
         $propbag->add('author',        'Serendipity Team');
-        $propbag->add('version',       '1.8');
+        $propbag->add('version',       '1.9');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -118,7 +118,9 @@ class serendipity_event_trackexits extends serendipity_event
                     if (empty($serendipity['encodeExitsCallback_entry_id'])) {
                         $this->links = array();
                     } else {
-                        $this->links = serendipity_db_query("SELECT id, link FROM {$serendipity['dbPrefix']}references WHERE entry_id = {$serendipity['encodeExitsCallback_entry_id']} AND type = ''", false, 'both', false, 'link', 'id');
+                        #echo "SELECT id, link FROM {$serendipity['dbPrefix']}references WHERE entry_id = {$serendipity['encodeExitsCallback_entry_id']} AND type = ''<br />\n";
+                        $this->links = serendipity_db_query("SELECT id, link FROM {$serendipity['dbPrefix']}references WHERE entry_id = {$serendipity['encodeExitsCallback_entry_id']} AND (type = '' OR type IS NULL)", false, 'both', false, 'link', 'id');
+                        #echo "<pre>" . print_r($this->links, true) . "</pre><br />\n";
                     }
 
                     foreach ($this->markup_elements as $temp) {
