@@ -1,7 +1,7 @@
-<?php # $Id: lang_bg.inc.php 1640 2007-03-08 18:06:13Z jwalker $
+<?php # $Id: lang_bg.inc.php 2089 2008-01-13 19:52:42Z jwalker $
 
 /**
- *  @version $Revision: 1640 $
+ *  @version $Revision: 2089 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
@@ -13,4 +13,4 @@
     @define('PLUGIN_COMMENTS_MAXENTRIES', 'Максимален брой на показваните коментари');
     @define('PLUGIN_COMMENTS_MAXENTRIES_BLAHBLAH', 'Колко коментара най-много да бъдат показани (по подразбиране: 15)');
     @define('PLUGIN_COMMENTS_ABOUT', '%s за%s');
-    @define('PLUGIN_COMMENTS_ANONYMOUS', 'anon');
+    @define('PLUGIN_COMMENTS_ANONYMOUS', 'анонимен');
