@@ -1,7 +1,7 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 2089 2008-01-13 19:52:42Z jwalker $
 
 /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 2089 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
@@ -13,4 +13,4 @@
     @define('PLUGIN_COMMENTS_MAXENTRIES', '    ');
     @define('PLUGIN_COMMENTS_MAXENTRIES_BLAHBLAH', '  -    ( : 15)');
     @define('PLUGIN_COMMENTS_ABOUT', '%s %s');
-    @define('PLUGIN_COMMENTS_ANONYMOUS', 'anon');
+    @define('PLUGIN_COMMENTS_ANONYMOUS', '');
