@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_en.inc.php 2086 2008-01-12 13:47:16Z brockhaus $
 
 /**
- *  @version $Revision: 1381 $
+ *  @version $Revision: 2086 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -15,4 +15,6 @@
 @define('PLUGIN_COMMENTS_MAXENTRIES_BLAHBLAH', 'How many comments will be shown? (Default: 15)');
 @define('PLUGIN_COMMENTS_ABOUT', '%s about%s');
 @define('PLUGIN_COMMENTS_ANONYMOUS', 'anon');
-?>
+
+@define('PLUGIN_COMMENTS_ADDURL', 'Add writers URL to');
+
