@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 1381 2006-08-15 10:14:56Z elf2000 $
+<?php # $Id: lang_en.inc.php 1716 2007-06-08 08:52:02Z garvinhicking $
 
 /**
- *  @version $Revision: 1381 $
+ *  @version $Revision: 1716 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -14,5 +14,6 @@
 @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_DESC', 'Only recent entries that are not on the front page will be shown. (Default: latest ' . $serendipity['fetchLimit'] . ' will be skipped)');
 @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_ALL', 'Show all');
 @define('PLUGIN_RECENTENTRIES_NUMBER_FROM_RADIO_RECENT', 'Skip front page items');
+@define('PLUGIN_RECENTENTRIES_RANDOMIZE', 'Show Random Articles');
+@define('PLUGIN_RECENTENTRIES_RANDOMIZE_DESC', 'If set, random articles will be selected.');
 
-?>
