@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_recententries.php 1719 2007-06-11 10:15:01Z garvinhicking $
+<?php # $Id: serendipity_plugin_recententries.php 2155 2008-03-02 15:23:01Z donchambers $
 
 // Contributed by Christian Machmeier <cm@redsplash.de>
 // Randomizing contributed by Christian Brabandt <cb@256bit.org>
@@ -20,18 +20,19 @@ class serendipity_plugin_recententries extends serendipity_plugin {
         $propbag->add('name',          PLUGIN_RECENTENTRIES_TITLE);
         $propbag->add('description',   PLUGIN_RECENTENTRIES_BLAHBLAH);
         $propbag->add('stackable',     true);
-        $propbag->add('author',        'Christian Machmeier, Christian Brabandt');
-        $propbag->add('version',       '1.7');
+        $propbag->add('author',        'Christian Machmeier, Christian Brabandt, Judebert, Don Chambers');
+        $propbag->add('version',       '2.0');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('configuration', array('title', 'number', 'number_from', 'dateformat', 'category', 'randomize'));
+        $propbag->add('configuration', array('title', 'number', 'number_from', 'dateformat', 'category', 'randomize', 'show_where'));
         $propbag->add('groups', array('FRONTEND_VIEWS'));
     }
 
     function introspect_config_item($name, &$propbag) {
+        global $serendipity;
         switch($name) {
             case 'title':
                 $propbag->add('type',        'string');
@@ -91,6 +92,7 @@ class serendipity_plugin_recententries extends serendipity_plugin {
 
                 $select_cats = array();
                 $select_cats['none'] = ALL_CATEGORIES;
+                $select_cats['_cur'] = PARENT_CATEGORY;
                 foreach($tmp_select_cats as $cidx => $tmp_select_cat) {
                     $select_cat = explode('|||', $tmp_select_cat);
                     if (!empty($select_cat[0]) && !empty($select_cat[1])) {
@@ -106,6 +108,15 @@ class serendipity_plugin_recententries extends serendipity_plugin {
                 $propbag->add('default',       'none');
                 break;
 
+            case 'show_where':
+                $select = array('extended' => PLUGIN_ITEM_DISPLAY_EXTENDED, 'overview' => PLUGIN_ITEM_DISPLAY_OVERVIEW, 'both' => PLUGIN_ITEM_DISPLAY_BOTH);
+                $propbag->add('type',        'select');
+                $propbag->add('select_values', $select);
+                $propbag->add('name',        PLUGIN_ITEM_DISPLAY);
+                $propbag->add('description', '');
+                $propbag->add('default',     'both');
+            break;
+                
             default:
                 return false;
         }
@@ -118,15 +129,28 @@ class serendipity_plugin_recententries extends serendipity_plugin {
         $number         = $this->get_config('number');
         $dateformat     = $this->get_config('dateformat');
         $category       = $this->get_config('category', 'none');
+        $show_where = $this->get_config('show_where', 'both');
+
+        if ($show_where == 'extended' && (!isset($serendipity['GET']['id']) || !is_numeric($serendipity['GET']['id']))) {
+            return false;
+        } else if ($show_where == 'overview' && isset($serendipity['GET']['id']) && is_numeric($serendipity['GET']['id'])) {
+            return false;
+        }
+
+        if ($category == '_cur') {
+            $category = $serendipity['GET']['category'];
+        }
         $title          = $this->get_config('title', $this->title);
         $number_from_sw = $this->get_config('number_from');
         $randomize      = ($this->get_config('randomize') == "yes") ? true : false ;
 
-        $sql_join   = '';
-        $sql_where  = '';
+        $sql_condition = array();
+        $sql_condition['joins'] = '';
+        $sql_condition['and']   = '';
         if ($category != 'none') {
-            $sql_join = 'LEFT OUTER JOIN ' . $serendipity['dbPrefix'] . 'entrycat AS ec ON id = ec.entryid
-                         LEFT OUTER JOIN ' . $serendipity['dbPrefix'] . 'category AS c  ON ec.categoryid = c.categoryid';
+            $sql_condition['joins'] .= 
+                'LEFT OUTER JOIN ' . $serendipity['dbPrefix'] . 'entrycat AS ec ON id = ec.entryid
+                 LEFT OUTER JOIN ' . $serendipity['dbPrefix'] . 'category AS c  ON ec.categoryid = c.categoryid';
                          
             $sql_categories = array();
             if (is_numeric($category)) {
@@ -140,7 +164,7 @@ class serendipity_plugin_recententries extends serendipity_plugin {
                 $category_parts[] = "\n" . implode(' AND ', serendipity_fetchCategoryRange($sql_category));
             }
 
-            $sql_where = ' AND (c.category_left BETWEEN ' . implode(' OR c.category_left BETWEEN ', $category_parts) . ')';
+            $sql_condition['and'] .= ' AND (c.category_left BETWEEN ' . implode(' OR c.category_left BETWEEN ', $category_parts) . ')';
         }
 
         if (!$number || !is_numeric($number) || $number < 1) {
@@ -170,15 +194,18 @@ class serendipity_plugin_recententries extends serendipity_plugin {
             $sql_order = "ORDER BY timestamp DESC ";
         }
 
+        $sql_condition['and'] .= "AND timestamp <= " . time();
+        serendipity_ACL_SQL($sql_condition, $category == 'none');
+
         $entries_query = "SELECT DISTINCT id,
                                 title,
                                 timestamp
-                           FROM {$serendipity['dbPrefix']}entries
-                                $sql_join
-                          WHERE isdraft = 'false' AND timestamp <= " . time() . "
-                                $sql_where
+                           FROM {$serendipity['dbPrefix']}entries AS e
+                                {$sql_condition['joins']}
+                          WHERE isdraft = 'false' {$sql_condition['and']}
                                 $sql_order
                                 $sql_number";
+        
         $entries = serendipity_db_query($entries_query);
 
         if (isset($entries) && is_array($entries)) {
