@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_remoterss.php 2041 2007-11-27 16:02:06Z garvinhicking $
+<?php # $Id: serendipity_plugin_remoterss.php 2075 2007-12-13 13:05:23Z garvinhicking $
 
 // Contributed by Udo Gerhards <udo@babyblaue-seiten.de>
 // OPML Contributed by Richard Thomas Harrison <rich@mibnet.plus.com>
@@ -257,13 +257,13 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
         $propbag->add('description',   PLUGIN_REMOTERSS_BLAHBLAH);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Udo Gerhards, Richard Thomas Harrison');
-        $propbag->add('version',       '1.11');
+        $propbag->add('version',       '1.12');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('configuration', array('number', 'use_rss_link', 'show_rss_element', 'escape_rss', 'displaydate', 'dateformat', 'sidebartitle', 'rssuri', 'charset', 'target', 'cachetime', 'feedtype', 'bulletimg', 'markup'));
+        $propbag->add('configuration', array('sidebartitle', 'feedtype', 'rssuri', 'show_rss_element', 'smarty', 'number', 'use_rss_link', 'escape_rss', 'displaydate', 'dateformat', 'charset', 'target', 'cachetime', 'bulletimg', 'markup'));
         $propbag->add('groups', array('FRONTEND_EXTERNAL_SERVICES'));
     }
 
@@ -375,11 +375,17 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                 $propbag->add('default', '');
                 break;
 
+            case 'smarty':
+                $propbag->add('type',        'boolean');
+                $propbag->add('name',        CATEGORY_PLUGIN_TEMPLATE);
+                $propbag->add('description', CATEGORY_PLUGIN_TEMPLATE_DESC);
+                $propbag->add('default',     false);
+                break;
 
             case 'displaydate':
                 $propbag->add('type', 'boolean');
                 $propbag->add('name', PLUGIN_REMOTERSS_DISPLAYDATE);
-                $propbag->add('description', PLUGIN_REMOTERSS_BLAHBLAH);
+                $propbag->add('description', PLUGIN_REMOTERSS_DISPLAYDATE_BLAHBLAH);
                 $propbag->add('default', 'true');
                 break;
 
@@ -452,6 +458,8 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
         if (!$cachetime || !is_numeric($cachetime)) {
             $cachetime = 10800; // 3 hours in seconds
         }
+        
+        $smarty = serendipity_db_bool($this->get_config('smarty'));
 
         if (trim($rssuri)) {
             $feedcache = $serendipity['serendipityPath'] . 'templates_c/remoterss_cache_' . md5(preg_replace('@[^a-z0-9]*@i', '', $rssuri)) . '.dat';
@@ -475,30 +483,53 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                     $escape_rss   = serendipity_db_bool($this->get_config('escape_rss'));
                     $i = 0;
                     $content = '';
+                    $smarty_items = array();
                     while (($showAll || ($i < $number)) && ($item = $c->getNextItem())) {
                         if (empty($item['title'])) {
                             continue;
                         }
 
+                        $content .= '<div class="rss_item">';
+
                         if ($use_rss_link) {
-                            $content .= '<a href="' . htmlspecialchars($this->decode($item['link'])) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . '>';
+                            $content .= '<div class="rss_link"><a href="' . htmlspecialchars($this->decode($item['link'])) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . '>';
                         }
 
                         if (!empty($bulletimg)) {
                             $content .= '<img src="' . $bulletimg . '" border="0" alt="*" /> ';
                         }
 
+                        $is_first = true;
                         foreach($rss_elements AS $rss_element) {
                             $rss_element = trim($rss_element);
+                            
+                            if (!$is_first) {
+                                $content .= '<span class="rss_' . preg_replace('@[^a-z0-9]@imsU', '', $rss_element) . '">';
+                            }
+
                             if ($escape_rss) {
                                 $content .= $this->decode($item[$rss_element]);
                             } else {
                                 $content .= htmlspecialchars($this->decode($item[$rss_element]));
                             }
+                            
+                            if ($smarty) {
+                                $item['display_elements'][preg_replace('@[^a-z0-9]@imsU', '', $rss_element)] = $this->decode($item[$rss_element]);
+                            }
+                            
+                            if (!$is_first) {
+                                $content .= '</span>';
+                            }
+
+                            if ($is_first && $use_rss_link) {
+                                $content .= '</a></div>'; // end of first linked element
+                            }
+                            $is_first = false;
                         }
 
-                        if ($use_rss_link) {
-                            $content .= '</a>';
+                        if ($is_first && $use_rss_link) {
+                            // No XML element has been configured.
+                            $content .= '</a></div>';
                         }
 
                         $content .= "<br />\n";
@@ -506,11 +537,32 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                         if (!($item['timestamp'] == -1) AND ($displaydate == 'true')) {
                             $content .= '<div class="serendipitySideBarDate">'
                                       . htmlspecialchars(serendipity_formatTime($dateformat, $item['timestamp'], false))
-                                      . '</div><br />';
+                                      . '</div>';
 
                         }
+                        
+                        if ($smarty) {
+                            $smarty_items['items'][$i] = $item;
+                            $smarty_items['items'][$i]['css_class'] = preg_replace('@[^a-z0-9]@imsU', '', $rss_element);
+                            foreach($item AS $key => $val) {
+                                $smarty_items['items'][$i]['decoded_' . str_replace(':', '_', $key)] = $this->decode($key);
+                            }
+                        }
+                        $content .= '</div>'; // end of rss_item
                         ++$i;
                     }
+                    
+                    if ($smarty) {
+                        $smarty_items['use_rss_link'] = $use_rss_link;
+                        $smarty_items['bulletimg']    = $bulletimg;
+                        $smarty_items['escape_rss']   = $escape_rss;
+                        $smarty_items['displaydate']  = $displaydate;
+                        $smarty_items['dateformat']   = $dateformat;
+                        $smarty_items['target']       = $target;
+
+                        $serendipity['smarty']->assign_by_ref('remoterss_items', $smarty_items);
+                        $content = $this->parseTemplate('plugin_remoterss.tpl');
+                    }
 
                     $this->debug('Caching Feed (' . strlen($content) . ' bytes)');
                     $fp = @fopen($feedcache, 'w');
@@ -571,7 +623,7 @@ class serendipity_plugin_remoterss extends serendipity_plugin {
                             }
 
                             if ($blogrolling === true && (!empty($text) || !empty($url))) {
-                                $content .= '&bull; <a href="' . htmlspecialchars($url) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . htmlspecialchars($text) . "</a>";
+                                $content .= '&bull; <a href="' . htmlspecialchars($url) . '" ' . (!empty($target) ? 'target="'.$target.'"' : '') . ' title="' . $text . '">' . $text . "</a>";
                                 if (isset($item['isRecent'])) {
                                     $content .= ' <span style="color: Red; ">*</span>';
                                 }
