@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_admin.php 1834 2007-08-09 09:31:16Z garvinhicking $
+<?php # $Id: serendipity_admin.php 2231 2008-04-16 10:11:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -59,7 +59,7 @@ if (defined('IS_up2date') && IS_up2date === true && IS_installed === true) {
 $is_logged_in = serendipity_userLoggedIn();
 
 if ($is_logged_in) {
-    $self_info = sprintf(USER_SELF_INFO, $serendipity['serendipityUser'], $serendipity['permissionLevels'][$serendipity['serendipityUserlevel']]);
+    $self_info = sprintf(USER_SELF_INFO, htmlspecialchars($serendipity['serendipityUser']), $serendipity['permissionLevels'][$serendipity['serendipityUserlevel']]);
 } else {
     $self_info = '';
 }
