@@ -1,16 +1,14 @@
-<?php # $Id: serendipity_define.js.php 7 2005-04-16 06:39:31Z s_bergmann $
+<?php # $Id: serendipity_define.js.php 1055 2006-04-06 09:14:11Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
+/* vim: set sts=4 ts=4 expandtab : */
 
 header('Content-type: application/x-javascript');
-include_once('serendipity_config.inc.php');
+include('serendipity_config.inc.php');
 ?>
 <!-- // Hide from older browsers
 // This page serves to carry through any variables without having to parse a complete .js file as .php
 
-var XHTML11 = <?php echo ($serendipity['XHTML11'] ? 'true' : 'false'); ?>;
+var XHTML11 = true;
 
 // -->
-<?php
-/* vim: set sts=4 ts=4 expandtab : */
-?>
